@@ -341,12 +341,13 @@ class transfer_learner():
 
     def get_best_model(self):
         '''
-        If self.MODEL_NAME + "_best.hdf5" exists in local folder, this will directly load the model without training.
+        If self.MODEL_NAME + "_best(2).hdf5" exists in local folder, this will directly load the model without training.
         '''
-
         if (not self.BEST_MODEL):
-            self.BEST_MODEL = load_model(self.MODEL_NAME + "_best.hdf5", 
-            compile = True) # 使用自定义的loss或者metric时，应compile = False，并手动调用compile
+            best_model_path = self.MODEL_NAME + "_best2.hdf5" # for two-stage training, use _best2.
+            if not os.path.isfile(best_model_path):
+                best_model_path = self.MODEL_NAME + "_best.hdf5"
+            self.BEST_MODEL = load_model(best_model_path, compile = True) # 使用自定义的loss或者metric时，应compile = False，并手动调用compile
         return self.BEST_MODEL
 
     def plot_best_model(self):
@@ -371,7 +372,7 @@ class transfer_learner():
         convert_keras_to_tflite(best_model_path, fname, v1) 
 
     def evaluate(self, X=None, y=None, N = 30):
-        
+
         if X is None:
             X = self.X_val
         if y is None:
